@@ -285,9 +285,9 @@ func TestBuild(t *testing.T) {
 			Goarch: "amd64",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    "",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    "",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 		{
@@ -298,9 +298,9 @@ func TestBuild(t *testing.T) {
 			Gomips: "softfloat",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    "",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    "",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 		{
@@ -311,9 +311,9 @@ func TestBuild(t *testing.T) {
 			Gomips: "softfloat",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    "",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    "",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 		{
@@ -323,9 +323,9 @@ func TestBuild(t *testing.T) {
 			Goarch: "amd64",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    "",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    "",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 		{
@@ -336,9 +336,9 @@ func TestBuild(t *testing.T) {
 			Goarm:  "6",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    "",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    "",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 		{
@@ -348,9 +348,9 @@ func TestBuild(t *testing.T) {
 			Goarch: "amd64",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    ".exe",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    ".exe",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 		{
@@ -360,9 +360,9 @@ func TestBuild(t *testing.T) {
 			Goarch: "wasm",
 			Type:   artifact.Binary,
 			Extra: map[string]interface{}{
-				"Ext":    ".wasm",
-				"Binary": "foo-v5.6.7",
-				"ID":     "foo",
+				artifact.ExtraExt:    ".wasm",
+				artifact.ExtraBinary: "foo-v5.6.7",
+				artifact.ExtraID:     "foo",
 			},
 		},
 	})
@@ -766,7 +766,7 @@ func TestProcessFlags(t *testing.T) {
 		Goarch: "amd64",
 		Goarm:  "7",
 		Extra: map[string]interface{}{
-			"Binary": "binary",
+			artifact.ExtraBinary: "binary",
 		},
 	}
 
