@@ -152,7 +152,6 @@ func doRun(ctx *context.Context, brew config.Homebrew, cl client.Client) error {
 			artifact.ByGoos("darwin"),
 			artifact.ByGoos("linux"),
 		),
-		artifact.ByFormats("zip", "tar.gz"),
 		artifact.Or(
 			artifact.ByGoarch("amd64"),
 			artifact.ByGoarch("arm64"),
@@ -162,7 +161,13 @@ func doRun(ctx *context.Context, brew config.Homebrew, cl client.Client) error {
 				artifact.ByGoarm(brew.Goarm),
 			),
 		),
-		artifact.ByType(artifact.UploadableArchive),
+		artifact.Or(
+			artifact.And(
+				artifact.ByFormats("zip", "tar.gz"),
+				artifact.ByType(artifact.UploadableArchive),
+			),
+			artifact.ByType(artifact.UploadableBinary),
+		),
 	}
 	if len(brew.IDs) > 0 {
 		filters = append(filters, artifact.ByIDs(brew.IDs...))
@@ -271,22 +276,35 @@ func doBuildFormula(ctx *context.Context, data templateData) (string, error) {
 	return out.String(), nil
 }
 
-func installs(cfg config.Homebrew, artifacts []*artifact.Artifact) []string {
+func installs(cfg config.Homebrew, art *artifact.Artifact) []string {
 	if cfg.Install != "" {
 		return split(cfg.Install)
 	}
-	install := []string{}
-	bins := map[string]bool{}
-	for _, a := range artifacts {
-		for _, bin := range a.ExtraOr("Binaries", []string{}).([]string) {
-			if !bins[bin] {
-				install = append(install, fmt.Sprintf("bin.install %q", bin))
-			}
-			bins[bin] = true
+
+	install := map[string]bool{}
+	switch art.Type {
+	case artifact.UploadableBinary:
+		name := art.Name
+		bin := art.ExtraOr(artifact.ExtraBinary, art.Name).(string)
+		install[fmt.Sprintf("bin.install %q => %q", name, bin)] = true
+	case artifact.UploadableArchive:
+		for _, bin := range art.ExtraOr(artifact.ExtraBinaries, []string{}).([]string) {
+			install[fmt.Sprintf("bin.install %q", bin)] = true
 		}
 	}
-	log.Warnf("guessing install to be `%s`", strings.Join(install, " "))
-	return install
+
+	result := keys(install)
+	sort.Strings(result)
+	log.Warnf("guessing install to be %q", strings.Join(result, ", "))
+	return result
+}
+
+func keys(m map[string]bool) []string {
+	keys := make([]string, 0, len(m))
+	for k := range m {
+		keys = append(keys, k)
+	}
+	return keys
 }
 
 func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifacts []*artifact.Artifact) (templateData, error) {
@@ -300,7 +318,6 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 		Dependencies:  cfg.Dependencies,
 		Conflicts:     cfg.Conflicts,
 		Plist:         cfg.Plist,
-		Install:       installs(cfg, artifacts),
 		PostInstall:   cfg.PostInstall,
 		Tests:         split(cfg.Test),
 		CustomRequire: cfg.CustomRequire,
@@ -308,8 +325,8 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 	}
 
 	counts := map[string]int{}
-	for _, artifact := range artifacts {
-		sum, err := artifact.Checksum("sha256")
+	for _, art := range artifacts {
+		sum, err := art.Checksum("sha256")
 		if err != nil {
 			return result, err
 		}
@@ -322,7 +339,7 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 			cfg.URLTemplate = url
 		}
 
-		url, err := tmpl.New(ctx).WithArtifact(artifact, map[string]string{}).Apply(cfg.URLTemplate)
+		url, err := tmpl.New(ctx).WithArtifact(art, map[string]string{}).Apply(cfg.URLTemplate)
 		if err != nil {
 			return result, err
 		}
@@ -330,9 +347,10 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 		pkg := releasePackage{
 			DownloadURL:      url,
 			SHA256:           sum,
-			OS:               artifact.Goos,
-			Arch:             artifact.Goarch,
+			OS:               art.Goos,
+			Arch:             art.Goarch,
 			DownloadStrategy: cfg.DownloadStrategy,
+			Install:          installs(cfg, art),
 		}
 
 		counts[pkg.OS+pkg.Arch]++
