@@ -9,7 +9,6 @@ import (
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/middleware/errhandler"
 	"github.com/goreleaser/goreleaser/internal/middleware/logging"
-	"github.com/goreleaser/goreleaser/internal/middleware/skip"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/goreleaser/goreleaser/pkg/defaults"
@@ -40,13 +39,10 @@ func (Pipe) Run(ctx *context.Context) error {
 		ctx.Config.GiteaURLs.Download = strings.ReplaceAll(apiURL, "/api/v1", "")
 	}
 	for _, defaulter := range defaults.Defaulters {
-		if err := skip.Maybe(
-			defaulter,
-			logging.Log(
-				defaulter.String(),
-				errhandler.Handle(defaulter.Default),
-				logging.ExtraPadding,
-			),
+		if err := logging.Log(
+			defaulter.String(),
+			errhandler.Handle(defaulter.Default),
+			logging.ExtraPadding,
 		)(ctx); err != nil {
 			return err
 		}
