@@ -66,6 +66,7 @@ func killAndRm(t *testing.T) {
 
 // TODO: this test is too big... split in smaller tests? Mainly the manifest ones...
 func TestRunPipe(t *testing.T) {
+	testlib.CheckPath(t, "docker")
 	type errChecker func(*testing.T, error)
 	shouldErr := func(msg string) errChecker {
 		return func(t *testing.T, err error) {
@@ -862,7 +863,7 @@ func TestRunPipe(t *testing.T) {
 					Goos:   "linux",
 					Type:   artifact.Binary,
 					Extra: map[string]interface{}{
-						"ID": "nope",
+						artifact.ExtraID: "nope",
 					},
 				})
 			},
@@ -980,7 +981,7 @@ func TestRunPipe(t *testing.T) {
 								Goos:   os,
 								Type:   artifact.Binary,
 								Extra: map[string]interface{}{
-									"ID": bin,
+									artifact.ExtraID: bin,
 								},
 							})
 						}
@@ -995,7 +996,7 @@ func TestRunPipe(t *testing.T) {
 						Goos:   "linux",
 						Type:   artifact.LinuxPackage,
 						Extra: map[string]interface{}{
-							"ID": "mybin",
+							artifact.ExtraID: "mybin",
 						},
 					})
 				}
@@ -1047,6 +1048,8 @@ func TestRunPipe(t *testing.T) {
 }
 
 func TestRunPipeWhileUsingBuildpacks(t *testing.T) {
+	testlib.CheckPath(t, "packs")
+
 	type errChecker func(*testing.T, error)
 	shouldNotErr := func(t *testing.T, err error) {
 		t.Helper()
