@@ -14,7 +14,11 @@ type releasePackage struct {
 	SHA256      string
 	OS          string
 	Arch        string
-	Binaries    []string
+	Binaries    []binary
+}
+
+type binary struct {
+	Name, Target string
 }
 
 const foodTemplate = `local name = "{{ .Name }}"
@@ -37,8 +41,8 @@ food = {
             resources = {
                 {{- range $binary := $element.Binaries }}
                 {
-                    path = "{{ $binary }}",
-                    installpath = {{if ne $element.OS "windows"}}"bin/{{ $binary }}"{{else}}"bin\\{{ $binary }}"{{end}},
+                    path = "{{ $binary.Name }}",
+                    installpath = {{if ne $element.OS "windows"}}"bin/{{ $binary.Target }}"{{else}}"bin\\{{ $binary.Target }}"{{end}},
                     {{- if ne $element.OS "windows"}}
                     executable = true
                     {{- end }}
