@@ -4,7 +4,7 @@
 package static
 
 // ExampleConfig is the config used within goreleaser init.
-const ExampleConfig = `# This is an example .goreleaser.yml file with some sane defaults.
+const ExampleConfig = `# This is an example .goreleaser.yml file with some sensible defaults.
 # Make sure to check the documentation at https://goreleaser.com
 before:
   hooks:
