@@ -317,6 +317,13 @@ func (f *File) UnmarshalYAML(unmarshal func(interface{}) error) error {
 	return nil
 }
 
+// UniversalBinary setups macos universal binaries.
+type UniversalBinary struct {
+	ID           string `yaml:"id,omitempty"`
+	NameTemplate string `yaml:"name_template,omitempty"`
+	Replace      bool   `yaml:",omitempty"`
+}
+
 // Archive config used for the archive.
 type Archive struct {
 	ID                        string            `yaml:",omitempty"`
@@ -689,6 +696,8 @@ type Project struct {
 	GoMod           GoMod            `yaml:"gomod,omitempty"`
 	Announce        Announce         `yaml:"announce,omitempty"`
 
+	UniversalBinaries []UniversalBinary `yaml:"universal_binaries,omitempty"`
+
 	// this is a hack ¯\_(ツ)_/¯
 	SingleBuild Build `yaml:"build,omitempty"`
 
@@ -717,6 +726,7 @@ type Announce struct {
 	Teams      Teams      `yaml:"teams,omitempty"`
 	SMTP       SMTP       `yaml:"smtp,omitempty"`
 	Mattermost Mattermost `yaml:"mattermost,omitempty"`
+	Telegram   Telegram   `yaml:"telegram,omitempty"`
 }
 
 type Twitter struct {
@@ -781,6 +791,12 @@ type SMTP struct {
 	InsecureSkipVerify bool     `yaml:"insecure_skip_verify,omitempty"`
 }
 
+type Telegram struct {
+	Enabled         bool   `yaml:"enabled,omitempty"`
+	MessageTemplate string `yaml:"message_template,omitempty"`
+	ChatID          int64  `yaml:"chat_id,omitempty"`
+}
+
 // Load config file.
 func Load(file string) (config Project, err error) {
 	f, err := os.Open(file) // #nosec
